<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Category;
use Illuminate\Http\Request;

class MarksController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $rows = Category::where('type', 'car')->where('parent_id', '=', null)->orderByDesc('id')->get();
        return view('admin.marks.index', compact('rows'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.marks.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'name_ar' => 'required',
            'name_en' => 'required',
            'image' => 'required|image'
        ]);
        $category = new Category();
        $category['name->ar'] = $request['name_ar'];
        $category['name->en'] = $request['name_en'];
        $category['type'] = 'car';
        $category->setImageAttribute();
        $category->save();
        return redirect()->route('marks.index')->with('message', 'تم اضافه البنك بنجاح');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = Category::find($id);
        return view('admin.marks.edit', compact('row'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'name_ar' => 'required',
            'name_en' => 'required',
            'image' => 'image'
        ]);
        $category = Category::find($id);
        $category['name->ar'] = $request['name_ar'];
        $category['name->en'] = $request['name_en'];
        if ($request->hasFile('image')) $category->setImageAttribute();

        $category->update();
        return redirect()->route('marks.index')->with('message', 'تم تعديل البنك بنجاح');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        Category::destroy($id);
        return redirect()->back()->with('message', 'تم الحذف بنجاح');
    }
}
