<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Resources\CategoryResource;
use App\Http\Resources\CityResource;
use App\Http\Resources\ProductResource;
use App\Http\Resources\QuestionResource;
use App\Http\Resources\ReasonResource;
use App\Models\Category;
use App\Models\Product;
use App\Models\City;
use App\Models\Question;
use App\Models\ReportReason;
use App\Models\Setting;
use Illuminate\Http\Request;

class DataController extends Controller
{
    public function reasons_report(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $reasons = ReportReason::all();
        $data = ReasonResource::collection($reasons);
        return response()->json(['value' => 'true', 'data' => $data, 'code' => 200]);
    }

    public function search(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        if (request()->header('Authorization')) {
            if (!$user = JWTAuth::parseToken()->authenticate()) {
                return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
            }
        }
        $validator = \Validator::make($request->all(), [
            'search' => 'required',
        ]);
        if ($validator->passes()) {
            $products = Product::where("title", "LIKE", "%" . $request['search'] . "%")->paginate(10);
            return ProductResource::collection($products)->additional(['value' => true, 'code' => 200]);
        }
        return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
    }

    public function questions(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        return QuestionResource::collection(Question::paginate(10))->additional(['value' => true, 'code' => 200]);
    }

    public function categories_parent(Request $request, $type)
    {
        $categories = Category::where('parent_id', '=', null)->where('type', $type)->get();
        $data = CategoryResource::collection($categories);
        return response()->json(['value' => true, 'data' => $data, 'code' => 200]);
    }

    public function sub_categories(Request $request, $id)
    {
        $categories = Category::where('parent_id', $id)->get();
        $data = CategoryResource::collection($categories);
        return response()->json(['value' => true, 'data' => $data, 'code' => 200]);
    }

    public function pages(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $setting = Setting::first();
        $arr['about'] = $setting->about ? $setting->about[$lang] : '';
        $arr['police'] = $setting->police ? $setting->police[$lang] : '';
        $data[] = $arr;
        return response()->json(['value' => true, 'data' => $data, 'code' => 200]);
    }
    
     public function cities(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $cities = City::all();
        $data = CityResource::collection($cities);
        return response()->json(['value' => true, 'data' => $data, 'code' => 200]);
    }
}
